% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fitDistribution.R
\name{fitZIG}
\alias{fitZIG}
\title{fitZIG}
\usage{
fitZIG(counts, scale = "default", verbose = TRUE)
}
\arguments{
\item{counts}{a phyloseq object or a matrix of counts with features (OTUs,
ASVs, genes) by row and samples by column.}

\item{scale}{Character vector, either \code{median} or \code{default} to
choose between the median of the library size or one thousand to scale
normalization factors.}

\item{verbose}{an optional logical value. If \code{TRUE} information on the
steps of the algorithm is printed. Default \code{verbose = TRUE}.}
}
\value{
A data frame containing the continuity corrected logarithms of the
average fitted values for each row of the matrix of counts in the \code{Y}
column, and the estimated probability to observe a zero in the \code{Y0}
column.
}
\description{
Fit a Zero-Inflated Gaussian (ZIG) distribution for each taxon of the count
data. The model estimation procedure is performed by metagenomeSeq
\code{\link{fitZig}} function without assuming the presence of any group in
the samples (design matrix equal to a column of ones.)
}
\examples{
# Generate some random counts
counts = matrix(rnbinom(n = 60, size = 3, prob = 0.5), nrow = 10, ncol = 6)

# Fit model on the counts matrix
ZIG <- fitZIG(counts, scale = "median")
head(ZIG)
}
